summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorIikka Eklund <iikka.eklund@qt.io>2021-01-29 11:10:40 +0200
committerIikka Eklund <iikka.eklund@qt.io>2021-02-01 08:19:41 +0200
commit53c3d955bafe75936dd281d479fca9746f5a8990 (patch)
tree78cd1699c4ddace9b8a1118c26eeb0af5f5fed4a
parent3e89237d9640ae9fb0b7e405a669864de403546d (diff)
conanfile.py: Use QTDIR instead of QT_PATH
There's an established environment variable for this though, QTDIR. This environment variable is also set by Qt Creator by default. So the Conan recipes should accept this environment variable instead. This requires a change in the matching conan profile files where the path to Qt installation is injected to env. Task-number: QTBUG-90583 Change-Id: I0beaff832325008dd1778a03d2885b6190def754 Reviewed-by: Kai Koehne <kai.koehne@qt.io>
-rw-r--r--conanfile.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/conanfile.py b/conanfile.py
index 25d199d5b..dd86a61ac 100644
--- a/conanfile.py
+++ b/conanfile.py
@@ -54,11 +54,11 @@ class Qt3D(ConanFile):
pass
def _get_cmake_prefix_path(self):
# 'QT_PATH' provided as env variable in profile file which is part of the Qt essential binary
# package(s). Installed under .conan/profiles
- cmake_prefix_path = os.environ.get("QT_PATH")
+ cmake_prefix_path = os.environ.get("QTDIR")
if not cmake_prefix_path:
- raise QtConanError("'QT_PATH' not defined! The 'QT_PATH' needs to point to Qt installation directory.")
+ raise QtConanError("'QTDIR' not defined! The 'QTDIR' needs to point to Qt installation directory.")
print(f"CMAKE_PREFIX_PATH for '{self.name}/{self.version}' build is: {cmake_prefix_path}")
return cmake_prefix_path
@@ -73,7 +73,7 @@ class Qt3D(ConanFile):
ext = ".bat" if tools.os_info.is_windows else ""
qtcmake = os.path.abspath(os.path.join(qt_install_path, "bin", "qt-cmake" + ext))
if not os.path.exists(qtcmake):
- raise QtConanError(f"Unable to locate {qtcmake} from 'QT_PATH': {qt_install_path}")
+ raise QtConanError(f"Unable to locate {qtcmake} from 'QTDIR': {qt_install_path}")
return qtcmake
def _get_cmake_tool(self):
@@ -54,11 +54,11 @@ class Qt3D(ConanFile):
pass
def _get_cmake_prefix_path(self):
- # 'QT_PATH' provided as env variable in profile file which is part of the Qt essential binary
+ # 'QTDIR' provided as env variable in profile file which is part of the Qt essential binary
# package(s). Installed under .conan/profiles